FeedbackLayer = class("FeedbackLayer")

--new
function FeedbackLayer:new( o )
	o = o or {}
	setmetatable(o, self)
	self.__index = self
	return o
end

-- create
function FeedbackLayer:create( data )
	local proxy = cc.CCBProxy:create()
	ccb["FeedbackLayer"] = self
	ccb["FeedbackLayerOwner"] = self
	self.topNode = CCBReaderLoad("ccb/FeedbackLayer.ccbi", proxy, self)
	self.data = data

	-- set button onlick
	self.btnBack.owner = self
	self.btnSend.owner = self

	self:initUI()
	self:localization()
	return self
end

function FeedbackLayer:initUI(  )
	SetTouchEventForLayer(self.lySwallow, TouchSwallow)
	self:initInputText()
	self:addRobotMsg()
end

function FeedbackLayer:localization(  )
	self.lbTitle:setString(MultiLan("feedback_title"))
	self.lbTitleHistory:setString(MultiLan("feedback_title_history"))
	self.lbTitleSend:setString(MultiLan("feedback_title_send"))
	self.btnBack:setTitleForState(MultiLan("feedback_btn_back"), cc.CONTROL_STATE_NORMAL)
	self.btnSend:setTitleForState(MultiLan("feedback_btn_send"), cc.CONTROL_STATE_NORMAL)
end

function FeedbackLayer:initInputText(  )
	self.editbox = cc.EditBox:create(self.lbInputHere:getContentSize(), cc.Scale9Sprite:createWithSpriteFrameName("pic_suiyiaaa.png"))
	self.editbox:setText("")
	self.editbox:setPlaceHolder(MultiLan("feedback_input_placeholder"))
	self.editbox:setPosition(self.lbInputHere:getPosition())
	-- self.editbox:setFontSize(25)
	self.editbox:setFontColor(COLOR_CONFIGS.feedback)
	self.editbox:setFont(DefaultFontName, 25)
	self.editbox:setPlaceholderFontSize(25)
	self.editbox:setMaxLength(60)
	self.editbox:setContentSize(self.lbInputHere:getContentSize())

	self.lbInputHere:getParent():addChild(self.editbox)
	self.lbInputHere:removeFromParent()		-- remove after used
end

function FeedbackLayer:addRobotMsg(  )
	local msgLayer = self.lyHistoryLabel
	local msgSize = msgLayer:getContentSize()

	local msgContentLayer = CreateLayer(msgSize, 1, Pos(msgSize))
	local descAreaSize = msgSize
	local descArea = CreateLayer(descAreaSize, 1, Pos(descAreaSize, 0.5, 0.5))
	msgContentLayer:addChild(descArea)
	
	local layer = cc.Layer:create()
	local richText = ccui.RichText:create()
	richText:ignoreContentAdaptWithSize(false)
	richText:setAnchorPoint(cc.p(0.5, 0.5))
	richText:setContentSize(descAreaSize)
	layer:addChild(richText)

	richText:pushBackElement(ccui.RichElementText:create(1, COLOR_RED, 255, MultiLan("feedback_name_system"), DefaultFontName, FontSize4))
	richText:pushBackElement(ccui.RichElementNewLine:create())
	richText:pushBackElement(ccui.RichElementText:create(1, COLOR_CONFIGS.feedback, 255, MultiLan("feedback_first_word"), DefaultFontName, FontSize4))
	richText:pushBackElement(ccui.RichElementNewLine:create())
	
	local realHeight = richText:getTextMaxHeight()
	richText:setPosition(cc.p(descAreaSize.width / 2, descAreaSize.height / 2 + math.max(0, realHeight - descAreaSize.height)))
	layer:setContentSize(cc.size(descAreaSize.width, math.max(descAreaSize.height, realHeight)))
	local scrollView = CreateScrollViewByFather(descArea, layer, cc.p(0, math.min(0, descAreaSize.height - realHeight)), kScrollViewDirectionVertical)

	msgLayer:addChild(msgContentLayer)
	self.scrollView = scrollView
	self.richText = richText
end

function FeedbackLayer:appendMsg( msg )
	local richText = self.richText
	richText:pushBackElement(ccui.RichElementText:create(1, COLOR_RED, 255, UserSelfInfo.name, DefaultFontName, FontSize4))
	richText:pushBackElement(ccui.RichElementNewLine:create())
	richText:pushBackElement(ccui.RichElementText:create(1, COLOR_CONFIGS.feedback, 255, msg, DefaultFontName, FontSize4))
	richText:pushBackElement(ccui.RichElementNewLine:create())

	local msgLayer = self.lyHistoryLabel
	local msgSize = msgLayer:getContentSize()
	local descAreaSize = msgSize
	local scrollView = self.scrollView
	local realHeight = richText:getTextMaxHeight()
	richText:setPosition(cc.p(descAreaSize.width / 2, descAreaSize.height / 2 + math.max(0, realHeight - descAreaSize.height)))
	scrollView:setContentSize(cc.size(descAreaSize.width, math.max(descAreaSize.height, realHeight)))
	-- scrollView:setContentOffset(cc.p(0, math.max(0, realHeight - descAreaSize.height)))
	scrollView:setContentOffset(cc.p(0, 0))
	scrollView:updateInset()
end

function FeedbackLayer:onSendBtn()
	local cbAddMsg = function ( retData )
		if retData.ret == 0 then
			self.owner.editbox:setText("")
		end
	end
	local msg = self.owner.editbox:getText()
	ccdump(msg, "msg")
	if msg ~= nil and msg ~= "" then
		HttpSend("feedback/addmsg", {"msg=" .. msg}, cbAddMsg)
		self.owner:appendMsg(self.owner.editbox:getText())
	end
end

function FeedbackLayer:onBackBtn()
	removeSelf(self.owner.topNode)
end