require "lua/NewTcpSocket"

ChatLayer = class("ChatLayer")
ChatLayer.__index = ChatLayer

ChatLayer.isCreated = false
ChatLayer.topNode = nil
ChatLayer.editBox = nil
ChatLayer.curChannelId = ChatLayer.CHAT_CHANNEL_WORLD
ChatLayer.scrollView = {}
ChatLayer.richText = {}
ChatLayer.talkInfo = {}			--每个频道的内容数组，二维的
ChatLayer.talkInfoCount = {}	--每个频道多少句话
ChatLayer.recentChatPlayer = {}	--最近说话的人
ChatLayer.recentChatTime = {}	--最近聊天时间
ChatLayer.recentLayer = nil		--最近说话弹出层

ChatLayer.CHAT_RECENT_MAX = 16		--最近说话的最大人数
ChatLayer.CHAT_MAX_LINE = 30		--最多多少航
ChatLayer.CHAT_INTERVAL = 10		    --聊天间隔
ChatLayer.LAST_SEND_TEXT = ""		    --上次发言
ChatLayer.isShowedRecent = false	--是否显示过最近聊天
ChatLayer.CHAT_FACE_STR_ARR = {"O(∩_∩)O", "Σ( ° △ °|||)︴", "(*￣3￣)╭", "(*^—^*) ", "(*￣︿￣)", "〒▽〒"}		--聊天快捷表情
-- ChatLayer.CHAT_FACE_STR_ARR = {"\\smile", "\\sweat", "\\like", "\\shy", "\\wretched", "\\cry"}		--聊天快捷表情
ChatLayer.CHAT_FACE_PNG_ARR = {"face1.png","face2.png","face3.png","face4.png","face5.png","face6.png",}


ChatLayer.CHAT_CHANNEL_WORLD = 1	--世界频道
ChatLayer.CHAT_CHANNEL_BANGPAI = 2	--帮派频道
ChatLayer.CHAT_CHANNEL_MAX = 2		--频道数目

CHANNEL_STRING = {}
CHANNEL_STRING[1] = MultiLan("lan_world")
CHANNEL_STRING[2] = MultiLan("lan_union")

ccb["ChatLayer"] = ChatLayer
ChatLayerOwner = ChatLayerOwner or {}
ccb["ChatLayerOwner"] = ChatLayerOwner

local function onChatFaceClick(node)
	local tag = node:getTag()
	if tag > 0 and tag <= table.maxn(ChatLayer.CHAT_FACE_STR_ARR) then
		ChatLayer:SendChatText(ChatLayer.CHAT_FACE_STR_ARR[tag])
	end
end

function ChatLayer:ChatLayerInitOnce()
	for i = 1, self.CHAT_CHANNEL_MAX do
		self.recentChatPlayer[i]={}
		self.scrollView[i] = cc.ScrollView:create()
		local chatLayerBoard = ChatLayerOwner["mChatLayerBoard"]
		chatLayerBoard:addChild(self.scrollView[i])
		self.scrollView[i]:setViewSize(cc.size(chatLayerBoard:getContentSize().width, chatLayerBoard:getContentSize().height))
		self.scrollView[i]:setContentSize(cc.size(chatLayerBoard:getContentSize().width, chatLayerBoard:getContentSize().height))
		self.scrollView[i]:setPosition(cc.p(chatLayerBoard:getContentSize().width / 2, chatLayerBoard:getContentSize().height / 2))
		self.scrollView[i]:ignoreAnchorPointForPosition(false)
		self.scrollView[i]:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
		self.scrollView[i]:setClippingToBounds(true)
		self.scrollView[i]:setBounceable(true)
		self.scrollView[i]:setDelegate()
	end
	for i = 1, self.CHAT_CHANNEL_MAX do
		self.talkInfo[i] = {}
		self.recentChatTime[i] = 0
		self.talkInfoCount[i] = 0
		for j = 1, self.CHAT_MAX_LINE do
			self.talkInfo[i][j] = {}
		end
	end
	
	local faceCount = table.maxn(ChatLayer.CHAT_FACE_STR_ARR)
	for i=1, faceCount do
		ChatLayerOwner["mChatLayerFace"]:addChild(CreateCommonButton("face"..i..".png", cc.p(-35+70*i, 30), cc.size(50,50),onChatFaceClick), 0,i)
	end
	
	SetTouchEventForLayer(ChatLayerOwner["mChatClickLayer"], ChatLayerRecentLayerClick)
end

function ChatLayer:ChatLayerEnter()
	if self.isCreated then
		self.topNode:setVisible(true)
	else
		self.isCreated = true
		local proxy = cc.CCBProxy:create()
		self.topNode = CommonCreatePopup(CCBReaderLoad("ccb/ChatLayer.ccbi",proxy,ChatLayerOwner))
		
		self.editBox = cc.EditBox:create(cc.size(350, 40), cc.Scale9Sprite:createWithSpriteFrameName("board_account01.png"))
		local editLayer = ChatLayerOwner["mChatInputLayer"]
		editLayer:addChild(self.editBox)
		self.editBox:setReturnType(cc.KEYBOARD_RETURNTYPE_SEND)
		self.editBox:setInputMode(cc.EDITBOX_INPUT_MODE_SINGLELINE)
		self.editBox:setPlaceHolder(MultiLan("GCL_typeChatContent"))
		self.editBox:setPosition(cc.p(editLayer:getContentSize().width / 2, editLayer:getContentSize().height / 2))
		
		self:ChatLayerInitOnce()
		
		self:ChatLayerConnect()
		scheduler:scheduleScriptFunc(socketReceive, 0.1, false)
		scheduler:scheduleScriptFunc(ChatLayerBreath, 10, false)
		self:ChatLayerInit()
		
		--ccb多语言
		ChatLayerOwner["mChatLayerConfig"]:setTitleForState(MultiLan("button_setting"), 1)
		ChatLayerOwner["mChatLayerWorld"]:setTitleForState(MultiLan("chat_world"), 1)
		ChatLayerOwner["mChatLayerGonghui"]:setTitleForState(MultiLan("chat_union"), 1)
		ChatLayerOwner["mChatLayerSend"]:setTitleForState(MultiLan("button_send"), 1)
		ChatLayerOwner["mTitleChat"]:setString(ZGMultiLan("chat_title"))
	end
	self.editBox:setText("")
	
end

function ChatLayerBreath()
	if TcpNetworkStatus == TCP_NETWORK_NOT_CONNECTED then
		ChatLayer:ChatLayerConnect()
		-- cclog("tcp not connected")
	elseif TcpNetworkStatus == TCP_NETWORK_CONNECTED then
		local tmpTable = {id = 100}
		ChatLayer:ChatLayerSendInfo(tmpTable)					--发送心跳
		-- cclog("tcp breath")
--	elseif TcpNetworkStatus == TCP_NETWORK_CONNECTING then
--		cclog("tcp connecting")
	elseif TcpNetworkStatus == TCP_NETWORK_ERROR then
		-- cclog("tcp connect error")
	end
end

function ChatLayer:ChatLayerConnect()
	socketInit()
	local connectTable = {id = 101, token = USER_TOKEN}
	ChatLayer:ChatLayerSendInfo(connectTable)
	--TcpNetworkStatus = TCP_NETWORK_CONNECTING
end

function ChatLayer:ChatLayerExit()
	ChatLayer.topNode:setVisible(false)
end

function ChatLayer:ChatLayerInit()
	self.editBox:setText("")
	self.curChannelId = ChatLayer.CHAT_CHANNEL_WORLD
	for i = 1, self.CHAT_CHANNEL_MAX do
		if i == 1 then
			self.scrollView[i]:setVisible(true)
		else
			self.scrollView[i]:setVisible(false)
		end
	end
	
end

function ChatLayerRecentLayerClick()
	local chaterInfo = ChatLayer.recentChatPlayer[ChatLayer.curChannelId]
	if table.maxn(chaterInfo) == 0 then
		return
	end

	local backLayer = cc.Layer:create()
	backLayer:ignoreAnchorPointForPosition(false)
	backLayer:setContentSize(cc.size(560, 656))
	backLayer:setPosition(cc.p(320, 480))
	
	local function recentLayerClose()
		ChatLayer.recentLayer:removeFromParent(true)
	end
	
	local backSprite = cc.Sprite:createWithSpriteFrameName("board_middle.png")
	backLayer:addChild(backSprite)
	backSprite:setPosition(cc.p(backSprite:getContentSize().width / 2, backSprite:getContentSize().height / 2))
	
	local titleBackSprite = cc.Sprite:createWithSpriteFrameName("title_boardall.png")
	backLayer:addChild(titleBackSprite)
	titleBackSprite:setPosition(cc.p(backLayer:getContentSize().width / 2, backLayer:getContentSize().height - 4))
	
	-- local titleSprite = cc.Sprite:createWithSpriteFrameName("title_talknow.png")
	-- titleBackSprite:addChild(titleSprite)
	-- titleSprite:setPosition(cc.p(titleBackSprite:getContentSize().width / 2, titleBackSprite:getContentSize().height / 2))  
	titleBackSprite:addChild(CreateCommonLabel(ZGMultiLan("title_zuijinliaotian"),cc.p(titleBackSprite:getContentSize().width / 2, titleBackSprite:getContentSize().height / 2),24,COLOR_YELLOW))
	local closeButton = CreateCommonButton("icon_close.png", cc.p(0, 0), cc.size(50, 50), recentLayerClose)
	backLayer:addChild(closeButton)
	closeButton:setPosition(cc.p(backLayer:getContentSize().width - 42, backLayer:getContentSize().height - 35))
	
	local insideLayer = cc.Layer:create()
	insideLayer:ignoreAnchorPointForPosition(false)
	
	-- insideLayer:setContentSize(cc.size(500, 510))
	insideLayer:setContentSize(ChatLayerOwner["mChatClickLayer"]:getContentSize())
	backLayer:addChild(insideLayer)
	insideLayer:setPosition(cc.p(backLayer:getContentSize().width / 2, 358))
	
	
	for i = 1, math.min(16,table.maxn(chaterInfo)) do
		local tmp = math.mod((i-1), 4)
		local tmp2 = math.floor((i-1) / 4)
		local playerItem = CreateDetailButton(chaterInfo[i].role,chaterInfo[i].sex, chaterInfo[i].uid)
		insideLayer:addChild(playerItem)
		playerItem:setPosition(cc.p(insideLayer:getContentSize().width * (0.125 + 0.25 * tmp), insideLayer:getContentSize().height - insideLayer:getContentSize().height * (0.125 + 0.25 * tmp2)))
		playerItem:addChild(CreateCommonLabel(chaterInfo[i].name,Pos(playerItem:getContentSize(),0.5,-0.15),FontSize2))
		playerItem:addChild(CreateCommonLabel("Lv."..chaterInfo[i].level, Pos(playerItem:getContentSize(),0.5,0.14),FontSize2))
	end
	
	ChatLayer.recentLayer = CommonCreatePopup(backLayer)
end

function ChatLayer:ChatLayerChannelRefresh(channelId)
	-- cc.SpriteFrameCache:getInstance():addSpriteFrames("ccb/ccbResources/Activity.plist")
	local infoText = ccui.RichText:create()
	infoText:ignoreContentAdaptWithSize(false)
	infoText:ignoreAnchorPointForPosition(true)
	infoText:setPosition(cc.p(0, 0))
	local chatLayerBoard = ChatLayerOwner["mChatLayerBoard"]
	infoText:setContentSize(cc.size(chatLayerBoard:getContentSize().width, chatLayerBoard:getContentSize().height))
	for i = 1, self.talkInfoCount[channelId] do
		if self.talkInfo[channelId][i]["uid"] ~= 0 then
			infoText:pushBackElement(ccui.RichElementText:create(1, self.talkInfo[channelId][i]["channelColor"], 255, self.talkInfo[channelId][i]["channel"], DefaultFontName, 22))
			if self.talkInfo[channelId][i]["title"] ~= "" then
				infoText:pushBackElement(ccui.RichElementText:create(1, self.talkInfo[channelId][i]["titleColor"], 255, self.talkInfo[channelId][i]["title"], DefaultFontName, 22))
			end
			
			infoText:pushBackElement(ccui.RichElementText:create(1, COLOR_WHITE, 255, self.talkInfo[channelId][i]["name"]..": ", DefaultFontName, 22))
			local showfacepng = false
			for j =1 ,6 do
				if self.talkInfo[channelId][i]["info"] == self.CHAT_FACE_STR_ARR[j] then
					-- cclog("png is "..self.CHAT_FACE_PNG_ARR[j])
					-- local re2 = ccui.RichElementImage:create(2,cc.c3b(255, 255, 255),255,self.CHAT_FACE_PNG_ARR[j])
					
					-- infoText:insertElement(re2, 2)
					-- infoText:pushBackElement(re2)
					infoText:pushBackElement(ccui.RichElementText:create(1, COLOR_WHITE, 255, self.talkInfo[channelId][i]["info"], "Helvetica", 22))
					showfacepng = true
					break
				end
			end
			 
			
			if not showfacepng then
				infoText:pushBackElement(ccui.RichElementText:create(1, COLOR_WHITE, 255, self.talkInfo[channelId][i]["info"], DefaultFontName, 22))
			end
			-- RichElementImage
			-- cclog("info is "..self.talkInfo[channelId][i]["info"])
		elseif self.talkInfo[channelId][i]["uid"] == 0 then
			infoText:pushBackElement(ccui.RichElementText:create(1, self.talkInfo[channelId][i]["channelColor"], 255, self.talkInfo[channelId][i]["channel"], DefaultFontName, 22))
			infoText:pushBackElement(ccui.RichElementText:create(1, COLOR_WHITE, 255, self.talkInfo[channelId][i]["info"], DefaultFontName, 22))
		end
		
		infoText:pushBackElement(ccui.RichElementNewLine:create())
		--cclog("talk string %s", self.talkInfo[channelId][i])
	end
	infoText:formatText()
	
	local tmpLayer = cc.Layer:create()--cc.LayerGradient:create(cc.c4b(255, 0, 0, 255), cc.c4b(255, 0, 255, 255))
	tmpLayer:ignoreAnchorPointForPosition(true)
	tmpLayer:addChild(infoText)
	if infoText:getTextMaxHeight() <= chatLayerBoard:getContentSize().height then
		infoText:setContentSize(cc.size(chatLayerBoard:getContentSize().width, chatLayerBoard:getContentSize().height))
		tmpLayer:setContentSize(cc.size(chatLayerBoard:getContentSize().width, chatLayerBoard:getContentSize().height))
	else
		infoText:setContentSize(cc.size(chatLayerBoard:getContentSize().width, infoText:getTextMaxHeight()))
		tmpLayer:setContentSize(cc.size(chatLayerBoard:getContentSize().width, infoText:getTextMaxHeight()))
		infoText:setPosition(cc.p(0, infoText:getTextMaxHeight() - chatLayerBoard:getContentSize().height))
	end
	
	-- cclog("rich width height %d %d", tmpLayer:getContentSize().width, tmpLayer:getContentSize().height)
	--cclog("pos %.2f %.2f %.2f %.2f")
	
	
	
	self.scrollView[channelId]:setContainer(tmpLayer)
	self.scrollView[channelId]:updateInset()
	--chatLayerBoard:addChild(tmpLayer)
end

function ChatLayer:ChatLayerAddRecentData(stringTable)
	if stringTable.uid  == 0 then
		return
	end

	local chaterInfo = ChatLayer.recentChatPlayer[stringTable.clid]
	for i = 1, table.maxn(chaterInfo) do
		if chaterInfo[i].uid == stringTable.uid then	--表示存在，需要替换并放到最后
			table.remove(chaterInfo, i)
			table.insert(chaterInfo, stringTable)
			return
		end
	end
	table.insert(chaterInfo, stringTable)
end

function ChatLayer:getCanTalk()
	local settingTable = UserInfo:getUserInfo().data.info.setting
	if settingTable ~= nil and settingTable ~= CJSON_NULL and table.maxn(settingTable) > 0 then
		for i = 1, table.maxn(settingTable) do
			if settingTable[i] == 201 then
				return false
			end
		end
	end
	return true
end

function ChatLayer:addChannelString(stringTable)
	-- print("addChannelString", stringTable.clid,stringTable.title,stringTable.name,stringTable.s)
	if self:getCanTalk() == false then
		return
	end
	local chanId = stringTable.clid
	local title = stringTable.title
	local name = stringTable.name
	local info = stringTable.s
	self:ChatLayerAddRecentData(stringTable)
	
	--提示
	if self.topNode:isVisible() == false then
		GameGuide:setTalkNote(true)
	end
	if ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_WORLD]:isVisible() == false and chanId == ChatLayer.CHAT_CHANNEL_WORLD then
	    GameGuide:setTalkButtonNote(ChatLayerOwner["mChatLayerWorld"],true)
	elseif ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_BANGPAI]:isVisible() == false and chanId == ChatLayer.CHAT_CHANNEL_BANGPAI then
		GameGuide:setTalkButtonNote(ChatLayerOwner["mChatLayerGonghui"],true)
	end
	
	local function setTalkInfo(chatTable, chatInfo)
		if chatInfo.uid == 0 then
			chatTable["channel"] = "["..MultiLan("lan_system").."]"
			chatTable["channelColor"] = COLOR_RED
		else
			chatTable["channel"] = "["..CHANNEL_STRING[chatInfo.clid].."]"
			chatTable["channelColor"] = COLOR_GREEN
		end
		if chatInfo.uid == UserSelfInfo.uid then
			-- print("="..UserSelfInfo.title)
			chatInfo.title = UserSelfInfo.title
		end
		chatTable["uid"] = chatInfo.uid
		chatTable["name"] = ""
		if chatInfo.name ~= nil and chatInfo.name ~= "" then
			chatTable["name"] = chatInfo.name
		end
		chatTable["info"] = ""
		if chatInfo.s ~= nil and chatInfo.s ~= "" then
			chatTable["info"] = chatInfo.s
		end
		chatTable["titleColor"] = COLOR_WHITE
		chatTable["title"] = ""
		if chatInfo.title ~= nil and chatInfo.title ~= 0 then
			chatTable["title"] = "[" .. MultiLan("description_" .. chatInfo.title) .. "]"
			if chatInfo.title-100 > 0 and chatInfo.title-100 <= table.maxn(TITLE_COLOR_TAG) then
				chatTable["titleColor"] = EQUIP_COLOR_ARR[TITLE_COLOR_TAG[chatInfo.title-100]]
			end
		end
		-- print("setTalkInfo",chatTable["uid"],chatTable["name"],chatTable["info"],chatTable["title"])
	end
	
	if self.talkInfoCount[chanId] == self.CHAT_MAX_LINE then
		for i = 1, self.CHAT_MAX_LINE - 1 do
			self.talkInfo[chanId][i]["channel"] = self.talkInfo[chanId][i+1]["channel"]
			self.talkInfo[chanId][i]["channelColor"] = self.talkInfo[chanId][i+1]["channelColor"]
			self.talkInfo[chanId][i]["title"] = self.talkInfo[chanId][i+1]["title"]
			self.talkInfo[chanId][i]["titleColor"] = self.talkInfo[chanId][i+1]["titleColor"]
			self.talkInfo[chanId][i]["name"] = self.talkInfo[chanId][i+1]["name"]
			self.talkInfo[chanId][i]["info"] = self.talkInfo[chanId][i+1]["info"]
			self.talkInfo[chanId][i]["uid"] = self.talkInfo[chanId][i+1]["uid"]
		end

		setTalkInfo(self.talkInfo[chanId][self.CHAT_MAX_LINE], stringTable)
	else
		self.talkInfoCount[chanId] = self.talkInfoCount[chanId]+1
		self.talkInfo[chanId][self.talkInfoCount[chanId]] = {}
		setTalkInfo(self.talkInfo[chanId][self.talkInfoCount[chanId]], stringTable)
	end
	self:ChatLayerChannelRefresh(chanId)
end

function ChatLayer:ChatLayerSendInfo(sendTable)
	local mp = require "lua/MessagePack"
	local mpac = mp.pack(sendTable)
	local lib = require"struct"
	local tmpStr = lib.pack(">i2", string.len(mpac))
	local finalString = tostring(tmpStr) .. tostring(mpac)
	socketSend(finalString)  
end

function ChatLayer:SendChatText(text)
	if UserSelfInfo.level < 5 then
		CommonNote(MultiLan("chat_level_limit"))
		return 
	end
	
	if os.time() - self.recentChatTime[self.curChannelId] < self.CHAT_INTERVAL then
		CommonNote(MultiLan("chat_too_fast"))
		return
	end
	
	if self.LAST_SEND_TEXT == text then
		self.CHAT_INTERVAL = self.CHAT_INTERVAL*2
	else
		self.CHAT_INTERVAL = math.max(10, self.CHAT_INTERVAL*0.5)
	end
	
	self.LAST_SEND_TEXT = text
	if self.LAST_SEND_TEXT == nil then
		self.LAST_SEND_TEXT = ""
	end

	self.recentChatTime[self.curChannelId] = os.time()
	tolua.cast(self.editBox, "cc.EditBox"):setText("")
	-- cclog("input text %s", text)
	local strLen = GetUTF8LogicStrLen(text)
	if strLen <= 0 or strLen > 40 then
		CreateSmallPopupWithCancel(nil, CreateCommonLabel(MultiLan("GCL_contentIsNull"), nil, FontSize3), nil)
		return
	end
	local tmpTable = {id = 102, clid = self.curChannelId, s = text}
	self:ChatLayerSendInfo(tmpTable)
end

function ChatLayer:ChatLayerReceiveInfo(rcvTable)
	-- print("ChatLayerReceiveInfo")
	for k,v in pairs(rcvTable) do
		-- print(k,v)
	end
	if rcvTable ~= nil then
		-- cclog("rcv table id %d", rcvTable.id)
		if rcvTable.id == 100 then
		elseif rcvTable.id == 101 then
			if rcvTable.ret == 0 then
				TcpNetworkStatus = TCP_NETWORK_CONNECTED
				if rcvTable.history ~= nil and rcvTable.history ~= CJSON_NULL then
					if self.isShowedRecent == false then
						self.isShowedRecent = true
						for i=1,table.maxn(rcvTable.history) do
							self:ChatLayerReceiveInfo(rcvTable.history[i])
						end
					end
				end
			end
		elseif rcvTable.id == 102 then
			--cclog(rcvTable.clid .. rcvTable.title .. rcvTable.name .. rcvTable.s .. " ")
			ChatLayer:addChannelString(rcvTable)
		elseif rcvTable.id == 201 then
			ChatLayer:addChannelString(rcvTable)
		elseif rcvTable.id == 202 then
		
		else
			AddServerBoardcast(rcvTable)
		end
	end
end

local function onChatLayerClose()
	ChatLayer.topNode:setVisible(false)
	GameGuide:setTalkNote(false)
end

local function onChatLayerConfig()
	BattleSetting:BattleSettingEnter()
end

local function onChatLayerWorld()
	ChatLayer.curChannelId = ChatLayer.CHAT_CHANNEL_WORLD
	tolua.cast(ChatLayerOwner["mChatLayerWorld"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_03.png"), cc.CONTROL_STATE_NORMAL)
	tolua.cast(ChatLayerOwner["mChatLayerWorld"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_03.png"), cc.CONTROL_STATE_HIGH_LIGHTED)
	tolua.cast(ChatLayerOwner["mChatLayerGonghui"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_04.png"), cc.CONTROL_STATE_NORMAL)
	tolua.cast(ChatLayerOwner["mChatLayerGonghui"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_04.png"), cc.CONTROL_STATE_HIGH_LIGHTED)
	ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_WORLD]:setVisible(true)
	ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_BANGPAI]:setVisible(false)
	GameGuide:setTalkButtonNote(ChatLayerOwner["mChatLayerWorld"],false)
end

local function onChatLayerGonghui()
	if UserSelfInfo.union == nil or UserSelfInfo.union == 0 then
		CommonNote(MultiLan("GCL_unionError"))
		return
	end

	ChatLayer.curChannelId = ChatLayer.CHAT_CHANNEL_BANGPAI
	tolua.cast(ChatLayerOwner["mChatLayerWorld"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_04.png"), cc.CONTROL_STATE_NORMAL)
	tolua.cast(ChatLayerOwner["mChatLayerWorld"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_04.png"), cc.CONTROL_STATE_HIGH_LIGHTED)
	tolua.cast(ChatLayerOwner["mChatLayerGonghui"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_03.png"), cc.CONTROL_STATE_NORMAL)
	tolua.cast(ChatLayerOwner["mChatLayerGonghui"], "cc.ControlButton"):setBackgroundSpriteForState(cc.Scale9Sprite:createWithSpriteFrameName("Event_btn_03.png"), cc.CONTROL_STATE_HIGH_LIGHTED)
	ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_WORLD]:setVisible(false)
	ChatLayer.scrollView[ChatLayer.CHAT_CHANNEL_BANGPAI]:setVisible(true)
	GameGuide:setTalkButtonNote(ChatLayerOwner["mChatLayerGonghui"],false)
end

local function onChatLayerSend()
	if ChatLayer:getCanTalk() == false then
		CommonNote(MultiLan("chat_close"), COLOR_RED)
		return
	end
	
	ChatLayer:SendChatText(tostring(tolua.cast(ChatLayer.editBox, "cc.EditBox"):getText()))
end

ChatLayer["onChatLayerClose"] = onChatLayerClose
ChatLayer["onChatLayerConfig"] = onChatLayerConfig
ChatLayer["onChatLayerWorld"] = onChatLayerWorld
ChatLayer["onChatLayerGonghui"] = onChatLayerGonghui
ChatLayer["onChatLayerSend"] = onChatLayerSend